==> happytimer_1.2.3.tar.gz: happytimer_1.2.3/callback.h <==
/*
 *  @Copyright (C) 2007 Kim Jin Chul (shriekout@gmail.com).
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*********************************************
 * callback.c 파일에 사용할 함수 원형들
 * *******************************************/

#ifndef _CALLBACK_H

#define _CALLBACK_H

#include <gtk/gtk.h>
#include <gst/gst.h>

void destroy(GtkWidget *widget, gpointer data);
void show_timer(GtkWidget *widget, gpointer data);
gboolean delete_event(GtkWidget *widget,
		GdkEvent *event,
		gpointer data);
void set_timer(GtkAdjustment *adj);
void timerGo(GtkWidget *widget, gpointer data);
void alarm_window_destroy(GtkWidget *widget);
void show_preference(GtkWidget *widget, gpointer data);
void on_rTSound_checkbox_clicked(GtkWidget *widget, gpointer data);
void on_tSound_checkbox_clicked(GtkWidget *widget, gpointer data);
void on_maxtimer_spin_changed(GtkWidget *widget, gpointer data);
void on_sound_combobox_changed(GtkWidget *widget, gpointer data);
void on_listenSound_button_clicked(GtkWidget *widget, gpointer data);
void on_image_button_clicked(GtkWidget *widget, gpointer data);
void image_preview(GtkWidget *widget, gpointer data);
gboolean bus_callback(GstBus *bus, GstMessage *msg, gpointer data);
void sound_changed(GtkWidget *widget, gpointer data);
void sound_preview(GtkWidget *widget, gpointer data);
void on_minus_button_clicked(GtkWidget *widget);
void on_plus_button_clicked(GtkWidget *widget);
void on_extension_button_clicked(GtkWidget *widget, gpointer data);
void on_set_detail_spin_changed(GtkWidget *widget, gpointer data);
void on_repeatTimer_checkbox_clicked(GtkWidget *widget, gpointer data);
void on_preset_combobox_changed(GtkWidget *widget, gpointer data);
void on_ppAdd_button_clicked(GtkWidget *widget, gpointer data);
void on_ppEdit_button_clicked(GtkWidget *widget, gpointer data);
void on_ppRemove_button_clicked(GtkWidget *widget, gpointer data);
void on_trayiconEbox_enter_notify_event(GtkWidget *widget, GdkEvent *event, gpointer data);
void on_trayiconEbox_leave_notify_event(GtkWidget *widget, GdkEvent *event, gpointer data);
void on_trayiconEbox_button_press_event(GtkWidget *widget, GdkEvent *event, gpointer data);
void on_timerPause_button_toggled(GtkWidget *widget, gpointer data);

#endif

==> happytimer_1.2.4.tar.gz: happytimer_1.2.4/callback.h <==
/*
 *  @Copyright (C) 2007 Kim Jin Chul (shriekout@gmail.com).
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/*********************************************
 * callback.c 파일에 사용할 함수 원형들
 * *******************************************/

#ifndef _CALLBACK_H

#define _CALLBACK_H

#include <gtk/gtk.h>
#include <gst/gst.h>

void destroy(GtkWidget *widget, gpointer data);
void show_timer(GtkWidget *widget, gpointer data);
gboolean delete_event(GtkWidget *widget,
		GdkEvent *event,
		gpointer data);
void set_timer(GtkAdjustment *adj);
void timerGo(GtkWidget *widget, gpointer data);
void alarm_window_destroy(GtkWidget *widget);
void show_preference(GtkWidget *widget, gpointer data);
void on_sound_checkbox_clicked(GtkWidget *widget, gpointer data);
void on_maxtimer_spin_changed(GtkWidget *widget, gpointer data);
void on_sound_combobox_changed(GtkWidget *widget, gpointer data);
void on_listenSound_button_clicked(GtkWidget *widget, gpointer data);
void on_image_button_clicked(GtkWidget *widget, gpointer data);
void image_preview(GtkWidget *widget, gpointer data);
gboolean bus_callback(GstBus *bus, GstMessage *msg, gpointer data);
void sound_changed(GtkWidget *widget, gpointer data);
void sound_preview(GtkWidget *widget, gpointer data);
void on_minus_button_clicked(GtkWidget *widget);
void on_plus_button_clicked(GtkWidget *widget);
void on_extension_button_clicked(GtkWidget *widget, gpointer data);
void on_set_detail_spin_changed(GtkWidget *widget, gpointer data);
void on_repeatTimer_checkbox_clicked(GtkWidget *widget, gpointer data);
void on_preset_combobox_changed(GtkWidget *widget, gpointer data);
void on_ppAdd_button_clicked(GtkWidget *widget, gpointer data);
void on_ppEdit_button_clicked(GtkWidget *widget, gpointer data);
void on_ppRemove_button_clicked(GtkWidget *widget, gpointer data);
void on_trayiconEbox_enter_notify_event(GtkWidget *widget, GdkEvent *event, gpointer data);
void on_trayiconEbox_leave_notify_event(GtkWidget *widget, GdkEvent *event, gpointer data);
void on_trayiconEbox_button_press_event(GtkWidget *widget, GdkEvent *event, gpointer data);
void on_timerPause_button_toggled(GtkWidget *widget, gpointer data);

struct t_struct {
	int hr;
	int min;
	int sec;
};

#endif
